;; Generated package description from bicep-ts-mode.el  -*- mode: lisp-data; no-byte-compile: t -*-
(define-package "bicep-ts-mode" "0.1.3.0.20250312.140118" "tree-sitter support for Bicep" 'nil :commit "a5cb3dc8e1507f8b8953f5cc4adcf2d2772d954f" :authors '(("Jostein Kjønigsen" . "jostein@kjonigsen.net")) :maintainer '("Jostein Kjønigsen" . "jostein@kjonigsen.net") :keywords '("bicep" "languages" "tree-sitter") :url "https://github.com/josteink/bicep-ts-mode")
